==> rc-ui-lib-0.2.4.tgz: package/lib/tabbar/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function _react() {
  var data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

var _ = require("..");

var _constant = require("../../utils/constant");

var _utils = require("../../../tests/utils");

// const activeClass = 'rc-tabbar-item--active';
describe('Tabbar', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should emit change event when click the tabbar item', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    var onChange, item;
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              value: 1,
              onChange: onChange
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "home-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "search"
            }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "friends-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "setting-o"
            }, "\u6807\u7B7E")));
            item = wrapper.find('.rc-tabbar-item');
            _context.next = 5;
            return item.at(0).simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith(0);
            _context.next = 8;
            return item.at(1).simulate('click');

          case 8:
            expect(onChange).toHaveBeenCalledTimes(1);

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should match active tab by name when using name prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    var onChange, item;
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              value: "a",
              onChange: onChange
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "b"
            }, "Tab")));
            item = wrapper.find('.rc-tabbar-item').at(1);
            _context2.next = 5;
            return item.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith('b'); // expect(item.hasClass(activeClass)).toEqual(true);

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should not render border when border prop is false', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
      border: false,
      value: "a"
    }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      name: "a"
    }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      name: "b"
    }, "Tab")));
    expect(wrapper.hasClass(_constant.BORDER_TOP_BOTTOM)).toEqual(false);
  });
  it('should render placeholder element when using placeholder prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    var restore;
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            restore = (0, _utils.mockGetBoundingClientRect)({
              height: 50
            });
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context3.next = 4;
            return (0, _utils.sleep)(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render cust prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    var restore;
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            restore = (0, _utils.mockGetBoundingClientRect)({
              height: 50
            });
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context4.next = 4;
            return (0, _utils.sleep)(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('render Custom icon correctly', function () {
    var _icon = {
      active: 'https://img.yzcdn.cn/vant/user-active.png',
      inactive: 'https://img.yzcdn.cn/vant/user-inactive.png'
    };
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, null, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      icon: function icon(ac) {
        return /*#__PURE__*/_react().default.createElement("img", {
          alt: "",
          src: ac ? _icon.active : _icon.inactive
        });
      }
    }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      icon: "friends-o"
    }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      icon: "setting-o"
    }, "\u6807\u7B7E")));
    expect(wrapper.html()).toMatchSnapshot();
  });
});

==> rc-ui-lib-0.3.0.tgz: package/lib/tabbar/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function _react() {
  var data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

var _ = require("..");

var _constant = require("../../utils/constant");

var _utils = require("../../../tests/utils");

var _mock = require("../../utils/dom/mock");

// const activeClass = 'rc-tabbar-item--active';
describe('Tabbar', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should emit change event when click the tabbar item', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    var onChange, item;
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              value: 1,
              onChange: onChange
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "home-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "search"
            }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "friends-o"
            }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              icon: "setting-o"
            }, "\u6807\u7B7E")));
            item = wrapper.find('.rc-tabbar-item');
            _context.next = 5;
            return item.at(0).simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith(0);
            _context.next = 8;
            return item.at(1).simulate('click');

          case 8:
            expect(onChange).toHaveBeenCalledTimes(1);

          case 9:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should match active tab by name when using name prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    var onChange, item;
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              value: "a",
              onChange: onChange
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "b"
            }, "Tab")));
            item = wrapper.find('.rc-tabbar-item').at(1);
            _context2.next = 5;
            return item.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith('b'); // expect(item.hasClass(activeClass)).toEqual(true);

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should not render border when border prop is false', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
      border: false,
      value: "a"
    }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      name: "a"
    }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      name: "b"
    }, "Tab")));
    expect(wrapper.hasClass(_constant.BORDER_TOP_BOTTOM)).toEqual(false);
  });
  it('should render placeholder element when using placeholder prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    var restore;
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            restore = (0, _mock.mockGetBoundingClientRect)({
              height: 50
            });
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context3.next = 4;
            return (0, _utils.sleep)(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render cust prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    var restore;
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            restore = (0, _mock.mockGetBoundingClientRect)({
              height: 50
            });
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, {
              fixed: true,
              placeholder: true,
              value: "a"
            }, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "a"
            }, "Tab"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
              name: "b"
            }, "Tab")));
            _context4.next = 4;
            return (0, _utils.sleep)(0);

          case 4:
            expect(wrapper.html()).toMatchSnapshot();
            restore();

          case 6:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('render Custom icon correctly', function () {
    var _icon = {
      active: 'https://img.yzcdn.cn/vant/user-active.png',
      inactive: 'https://img.yzcdn.cn/vant/user-inactive.png'
    };
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.Tabbar, null, /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      icon: function icon(ac) {
        return /*#__PURE__*/_react().default.createElement("img", {
          alt: "",
          src: ac ? _icon.active : _icon.inactive
        });
      }
    }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      icon: "friends-o"
    }, "\u6807\u7B7E"), /*#__PURE__*/_react().default.createElement(_.Tabbar.Item, {
      icon: "setting-o"
    }, "\u6807\u7B7E")));
    expect(wrapper.html()).toMatchSnapshot();
  });
});
